@@ -103,22 +103,49 @@ wd_IP_up(void)
 {
 	int rtn = WD_OK;
 	char path[WD_MAX_PATH_LEN];
-	char cmd[128];
+	char* command;
 	int i;
 
 	if (strlen(pool_config->delegate_IP) == 0)
-		return WD_NG;
+	{
+		ereport(LOG,
+			(errmsg("trying to acquire the delegate IP address, but delegate IP is not configured")));
+		return WD_OK;
+	}
 
-	wd_get_cmd(cmd,pool_config->if_up_cmd);
-	snprintf(path,sizeof(path),"%s/%s",pool_config->if_cmd_path,cmd);
-	rtn = exec_if_cmd(path,pool_config->if_up_cmd);
+	command = wd_get_cmd(pool_config->if_up_cmd);
+	if (command)
+	{
+		snprintf(path,sizeof(path),"%s/%s",pool_config->if_cmd_path,command);
+		rtn = exec_if_cmd(path,pool_config->if_up_cmd);
+		pfree(command);
+	}
+	else
+	{
+		ereport(LOG,
+			(errmsg("failed to acquire the delegate IP address"),
+				 errdetail("unable to parse the if_up_cmd:\"%s\"",pool_config->if_up_cmd)));
+		return WD_NG;
+	}
 
 	if (rtn == WD_OK)
 	{
-		wd_get_cmd(cmd,pool_config->arping_cmd);
-		snprintf(path,sizeof(path),"%s/%s",pool_config->arping_path,cmd);
-		rtn = exec_if_cmd(path,pool_config->arping_cmd);
+		command = wd_get_cmd(pool_config->arping_cmd);
+		if (command)
+		{
+			snprintf(path,sizeof(path),"%s/%s",pool_config->arping_path,command);
+			rtn = exec_if_cmd(path,pool_config->arping_cmd);
+			pfree(command);
+		}
+		else
+		{
+			rtn = WD_NG;
+			ereport(LOG,
+				(errmsg("failed to acquire the delegate IP address"),
+					 errdetail("unable to parse the arping_cmd:\"%s\"",pool_config->arping_cmd)));
+		}
 	}
+
 	if (rtn == WD_OK)
 	{
 		for (i = 0; i < WD_TRY_PING_AT_IPUP; i++)
@@ -126,7 +153,7 @@ wd_IP_up(void)
 			if (wd_is_ip_exists(pool_config->delegate_IP) == true)
 				break;
 			ereport(LOG,
-				(errmsg("watchdog bringing up delegate IP"),
+				(errmsg("waiting for the delegate IP address to become active"),
 					 errdetail("waiting... count: %d", i+1)));
 		}
 
@@ -136,72 +163,74 @@ wd_IP_up(void)
 
 	if (rtn == WD_OK)
 		ereport(LOG,
-			(errmsg("watchdog bringing up delegate IP, 'if_up_cmd' succeeded")));
+			(errmsg("successfully acquired the delegate IP:\"%s\"",pool_config->delegate_IP),
+				 errdetail("'if_up_cmd' returned with success")));
 	else
-		ereport(WARNING,
-			(errmsg("watchdog failed to bring up delegate IP, 'if_up_cmd' failed")));
+		ereport(LOG,
+			(errmsg("failed to acquire the delegate IP address"),
+				 errdetail("'if_up_cmd' failed")));
 	return rtn;
 }
 
-#define WD_TRY_PING_AT_IPDOWN 3
 int
 wd_IP_down(void)
 {
 	int rtn = WD_OK;
 	char path[WD_MAX_PATH_LEN];
-	char cmd[128];
-	int i;
+	char* command;
 
 	if (strlen(pool_config->delegate_IP) == 0)
-		return WD_NG;
-
-	wd_get_cmd(cmd,pool_config->if_down_cmd);
-	snprintf(path, sizeof(path), "%s/%s", pool_config->if_cmd_path, cmd);
-	rtn = exec_if_cmd(path,pool_config->if_down_cmd);
-
-	if (rtn == WD_OK)
 	{
-		for (i = 0; i < WD_TRY_PING_AT_IPDOWN; i++)
-		{
-			if (wd_is_ip_exists(pool_config->delegate_IP) == false)
-				break;
-		}
+		ereport(LOG,
+			(errmsg("trying to release the delegate IP address, but delegate IP is not configured")));
+		return WD_OK;
+	}
 
-		if (i >= WD_TRY_PING_AT_IPDOWN)
-			rtn = WD_NG;
+	command = wd_get_cmd(pool_config->if_down_cmd);
+	if (command)
+	{
+		snprintf(path, sizeof(path), "%s/%s", pool_config->if_cmd_path, command);
+		rtn = exec_if_cmd(path,pool_config->if_down_cmd);
+		pfree(command);
+	}
+	else
+	{
+		ereport(LOG,
+			(errmsg("failed to release the delegate IP address"),
+				 errdetail("unable to parse the if_down_cmd:\"%s\"",pool_config->if_down_cmd)));
+		return WD_NG;
 	}
 
 	if (rtn == WD_OK)
 	{
 		ereport(LOG,
-			(errmsg("watchdog bringing down delegate IP"),
-				 errdetail("if_down_cmd succeeded")));
+			(errmsg("successfully released the delegate IP:\"%s\"",pool_config->delegate_IP),
+				 errdetail("'if_down_cmd' returned with success")));
 	}
 	else
 	{
-		ereport(WARNING,
-			(errmsg("watchdog bringing down delegate IP, if_down_cmd failed")));
+		ereport(LOG,
+			(errmsg("failed to release the delegate IP:\"%s\"",pool_config->delegate_IP),
+				 errdetail("'if_down_cmd' failed")));
 	}
 	return rtn;
 }
 
 
-int
-wd_get_cmd(char * buf, char * cmd)
+char*
+wd_get_cmd(char* cmd)
 {
-	int i,j;
-	i = 0;
-	while(isspace(cmd[i]) != 0)
+	char *command = NULL;
+
+	if (cmd && *cmd)
 	{
-		i++;
+		char* tmp_str = pstrdup(cmd);
+		char* token = strtok(tmp_str," ");
+		if (token)
+			command = pstrdup(token);
+		pfree(tmp_str);
 	}
-	j = 0;
-	while(isspace(cmd[i]) == 0)
-	{
-		buf[j++] = cmd[i++];
-	}
-	buf[j] = '\0';
-	return strlen(buf);
+	return command;
 }
 
 static int
